==> currents-api-types-0.0.33.tgz: package/collective/types.ts <==
import { BlogId } from '../blog/id.types';
import { z } from 'zod';
import { SPECIAL_COLLECTIVE_ID_EXTERNAL } from '../specialities/collective/specialCollectiveId';
import { firebaseAdminIdParser } from './parsers.admin';

export enum CollectiveIdBrand {
  _ = '',
}

export type CollectiveId = string & (CollectiveIdBrand | typeof SPECIAL_COLLECTIVE_ID_EXTERNAL);
export type CollectiveAdminId = z.infer<typeof firebaseAdminIdParser>;
export interface CollectiveIdTrait {
  id: CollectiveId;
}

export interface CollectiveAdminsTrait {
  admins: BlogId[];
}

export interface CollectiveCore extends CollectiveAdminsTrait {
  admins: BlogId[];
  alias: string | null;
  blogs: BlogId[];
  collectiveSupport: boolean | null;
  common: boolean | null;
  commonBlogs: string[];
  description: string | null;
  gofa: boolean | null;
  hq: string | null;
  image: string | null;
  launched: boolean;
  location: string | null;
  mv: string | null;
  MV: string | null;
  name: string;
  planetFlyer: string | null;
  planetImage: string | null;
  planetName: string | null;
  planetPosition: Record<string, number | null>;
  price: number | null;
  radio: boolean | null;
  smallImage: string | null;
  sourceCollective: string;
  stripeProductID: string;
  subscribers: string[];
  type: string | null;
  updatedBy: string | null;
  verified: boolean;
}

export interface CollectiveDerived {
  nameLowercase: string;
  searchTokens: string[];
}

export interface CollectiveWithTime {
  created: Date;
}

export type Collective = CollectiveCore & CollectiveIdTrait;

==> currents-api-types-0.0.42.tgz: package/collective/types.ts <==
import { BlogId } from '../blog/id.types';
import { z } from 'zod';
import { SPECIAL_COLLECTIVE_ID_EXTERNAL } from '../specialities/collective/specialCollectiveId';
import { firebaseAdminIdParser } from './parsers.admin';
import { StripeProductId } from '../stripe/types';

export enum CollectiveIdBrand {
  _ = '',
}

export type CollectiveId = string & (CollectiveIdBrand | typeof SPECIAL_COLLECTIVE_ID_EXTERNAL);
export type CollectiveAdminId = z.infer<typeof firebaseAdminIdParser>;
export interface CollectiveIdTrait {
  id: CollectiveId;
}

export interface CollectiveAdminsTrait {
  admins: BlogId[];
}

export interface CollectiveCore extends CollectiveAdminsTrait {
  admins: BlogId[];
  alias?: string;
  blogs: BlogId[];
  collectiveSupport?: boolean;
  common?: boolean;
  commonBlogs: string[];
  description?: string;
  gofa?: boolean;
  hq?: string;
  image?: string;
  launched: boolean;
  location?: string;
  mv?: string;
  MV?: string;
  name: string;
  planetFlyer?: string;
  planetImage?: string;
  planetName?: string;
  planetPosition: Record<string, number | null>;
  price?: number;
  radio?: boolean;
  smallImage?: string;
  sourceCollective: string;
  stripeProductID: StripeProductId;
  subscribers: string[];
  type?: string;
  updatedBy?: string;
  verified: boolean;
}

export interface CollectiveDerived {
  nameLowercase: string;
  searchTokens: string[];
}

export interface CollectiveWithTime {
  created: Date;
}

export type Collective = CollectiveCore & CollectiveIdTrait;
